==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/template/ContainerTemplateFluentImpl.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.strimzi.api.kafka.model.ContainerEnvVar;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.strimzi.api.kafka.model.ContainerEnvVarBuilder;
import io.strimzi.api.kafka.model.ContainerEnvVarFluentImpl;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class ContainerTemplateFluentImpl<A extends ContainerTemplateFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ContainerTemplateFluent<A>{

    private List<ContainerEnvVarBuilder> env;

    public ContainerTemplateFluentImpl(){
    }
    public ContainerTemplateFluentImpl(ContainerTemplate instance){
            this.withEnv(instance.getEnv());

    }

    public A addToEnv(int index,ContainerEnvVar item){
            if (this.env == null) {this.env = new ArrayList<ContainerEnvVarBuilder>();}
            ContainerEnvVarBuilder builder = new ContainerEnvVarBuilder(item);_visitables.get("env").add(index >= 0 ? index : _visitables.get("env").size(), builder);this.env.add(index >= 0 ? index : env.size(), builder); return (A)this;
    }

    public A setToEnv(int index,ContainerEnvVar item){
            if (this.env == null) {this.env = new ArrayList<ContainerEnvVarBuilder>();}
            ContainerEnvVarBuilder builder = new ContainerEnvVarBuilder(item);
            if (index < 0 || index >= _visitables.get("env").size()) { _visitables.get("env").add(builder); } else { _visitables.get("env").set(index, builder);}
            if (index < 0 || index >= env.size()) { env.add(builder); } else { env.set(index, builder);}
             return (A)this;
    }

    public A addToEnv(ContainerEnvVar... items){
            if (this.env == null) {this.env = new ArrayList<ContainerEnvVarBuilder>();}
            for (ContainerEnvVar item : items) {ContainerEnvVarBuilder builder = new ContainerEnvVarBuilder(item);_visitables.get("env").add(builder);this.env.add(builder);} return (A)this;
    }

    public A addAllToEnv(Collection<ContainerEnvVar> items){
            if (this.env == null) {this.env = new ArrayList<ContainerEnvVarBuilder>();}
            for (ContainerEnvVar item : items) {ContainerEnvVarBuilder builder = new ContainerEnvVarBuilder(item);_visitables.get("env").add(builder);this.env.add(builder);} return (A)this;
    }

    public A removeFromEnv(ContainerEnvVar... items){
            for (ContainerEnvVar item : items) {ContainerEnvVarBuilder builder = new ContainerEnvVarBuilder(item);_visitables.get("env").remove(builder);if (this.env != null) {this.env.remove(builder);}} return (A)this;
    }

    public A removeAllFromEnv(Collection<ContainerEnvVar> items){
            for (ContainerEnvVar item : items) {ContainerEnvVarBuilder builder = new ContainerEnvVarBuilder(item);_visitables.get("env").remove(builder);if (this.env != null) {this.env.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromEnv(io.fabric8.kubernetes.api.builder.Predicate<ContainerEnvVarBuilder> predicate){
            if (env == null) return (A) this;
            final Iterator<ContainerEnvVarBuilder> each = env.iterator();
            final List visitables = _visitables.get("env");
            while (each.hasNext()) {
              ContainerEnvVarBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildEnv instead.
 * @return The buildable object.
 */
@Deprecated public List<ContainerEnvVar> getEnv(){
            return build(env);
    }

    public List<ContainerEnvVar> buildEnv(){
            return build(env);
    }

    public ContainerEnvVar buildEnv(int index){
            return this.env.get(index).build();
    }

    public ContainerEnvVar buildFirstEnv(){
            return this.env.get(0).build();
    }

    public ContainerEnvVar buildLastEnv(){
            return this.env.get(env.size() - 1).build();
    }

    public ContainerEnvVar buildMatchingEnv(io.fabric8.kubernetes.api.builder.Predicate<ContainerEnvVarBuilder> predicate){
            for (ContainerEnvVarBuilder item: env) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingEnv(io.fabric8.kubernetes.api.builder.Predicate<ContainerEnvVarBuilder> predicate){
            for (ContainerEnvVarBuilder item: env) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withEnv(List<ContainerEnvVar> env){
            if (this.env != null) { _visitables.get("env").removeAll(this.env);}
            if (env != null) {this.env = new ArrayList<ContainerEnvVarBuilder>(); for (ContainerEnvVar item : env){this.addToEnv(item);}} else { this.env = null;} return (A) this;
    }

    public A withEnv(ContainerEnvVar... env){
            if (this.env != null) {this.env.clear();}
            if (env != null) {for (ContainerEnvVar item :env){ this.addToEnv(item);}} return (A) this;
    }

    public Boolean hasEnv(){
            return env != null && !env.isEmpty();
    }

    public ContainerTemplateFluent.EnvNested<A> addNewEnv(){
            return new EnvNestedImpl();
    }

    public ContainerTemplateFluent.EnvNested<A> addNewEnvLike(ContainerEnvVar item){
            return new EnvNestedImpl(-1, item);
    }

    public ContainerTemplateFluent.EnvNested<A> setNewEnvLike(int index,ContainerEnvVar item){
            return new EnvNestedImpl(index, item);
    }

    public ContainerTemplateFluent.EnvNested<A> editEnv(int index){
            if (env.size() <= index) throw new RuntimeException("Can't edit env. Index exceeds size.");
            return setNewEnvLike(index, buildEnv(index));
    }

    public ContainerTemplateFluent.EnvNested<A> editFirstEnv(){
            if (env.size() == 0) throw new RuntimeException("Can't edit first env. The list is empty.");
            return setNewEnvLike(0, buildEnv(0));
    }

    public ContainerTemplateFluent.EnvNested<A> editLastEnv(){
            int index = env.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last env. The list is empty.");
            return setNewEnvLike(index, buildEnv(index));
    }

    public ContainerTemplateFluent.EnvNested<A> editMatchingEnv(io.fabric8.kubernetes.api.builder.Predicate<ContainerEnvVarBuilder> predicate){
            int index = -1;
            for (int i=0;i<env.size();i++) { 
            if (predicate.apply(env.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching env. No match found.");
            return setNewEnvLike(index, buildEnv(index));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ContainerTemplateFluentImpl that = (ContainerTemplateFluentImpl) o;
            if (env != null ? !env.equals(that.env) :that.env != null) return false;
            return true;
    }


    public class EnvNestedImpl<N> extends ContainerEnvVarFluentImpl<ContainerTemplateFluent.EnvNested<N>> implements ContainerTemplateFluent.EnvNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ContainerEnvVarBuilder builder;
        private final int index;
    
            EnvNestedImpl(int index,ContainerEnvVar item){
                    this.index = index;
                    this.builder = new ContainerEnvVarBuilder(this, item);
            }
            EnvNestedImpl(){
                    this.index = -1;
                    this.builder = new ContainerEnvVarBuilder(this);
            }
    
    public N and(){
            return (N) ContainerTemplateFluentImpl.this.setToEnv(index, builder.build());
    }
    public N endEnv(){
            return and();
    }

}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/template/ContainerTemplateFluentImpl.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.strimzi.api.kafka.model.ContainerEnvVar;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.strimzi.api.kafka.model.ContainerEnvVarBuilder;
import io.strimzi.api.kafka.model.ContainerEnvVarFluentImpl;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.SecurityContext;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class ContainerTemplateFluentImpl<A extends ContainerTemplateFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ContainerTemplateFluent<A>{

    private java.util.List<ContainerEnvVarBuilder> env;
    private SecurityContext securityContext;

    public ContainerTemplateFluentImpl(){
    }
    public ContainerTemplateFluentImpl(ContainerTemplate instance){
            this.withEnv(instance.getEnv());

            this.withSecurityContext(instance.getSecurityContext());

    }

    public A addToEnv(int index,ContainerEnvVar item){
            if (this.env == null) {this.env = new ArrayList<ContainerEnvVarBuilder>();}
            ContainerEnvVarBuilder builder = new ContainerEnvVarBuilder(item);_visitables.get("env").add(index >= 0 ? index : _visitables.get("env").size(), builder);this.env.add(index >= 0 ? index : env.size(), builder); return (A)this;
    }

    public A setToEnv(int index,ContainerEnvVar item){
            if (this.env == null) {this.env = new ArrayList<ContainerEnvVarBuilder>();}
            ContainerEnvVarBuilder builder = new ContainerEnvVarBuilder(item);
            if (index < 0 || index >= _visitables.get("env").size()) { _visitables.get("env").add(builder); } else { _visitables.get("env").set(index, builder);}
            if (index < 0 || index >= env.size()) { env.add(builder); } else { env.set(index, builder);}
             return (A)this;
    }

    public A addToEnv(ContainerEnvVar... items){
            if (this.env == null) {this.env = new ArrayList<ContainerEnvVarBuilder>();}
            for (ContainerEnvVar item : items) {ContainerEnvVarBuilder builder = new ContainerEnvVarBuilder(item);_visitables.get("env").add(builder);this.env.add(builder);} return (A)this;
    }

    public A addAllToEnv(Collection<ContainerEnvVar> items){
            if (this.env == null) {this.env = new ArrayList<ContainerEnvVarBuilder>();}
            for (ContainerEnvVar item : items) {ContainerEnvVarBuilder builder = new ContainerEnvVarBuilder(item);_visitables.get("env").add(builder);this.env.add(builder);} return (A)this;
    }

    public A removeFromEnv(ContainerEnvVar... items){
            for (ContainerEnvVar item : items) {ContainerEnvVarBuilder builder = new ContainerEnvVarBuilder(item);_visitables.get("env").remove(builder);if (this.env != null) {this.env.remove(builder);}} return (A)this;
    }

    public A removeAllFromEnv(Collection<ContainerEnvVar> items){
            for (ContainerEnvVar item : items) {ContainerEnvVarBuilder builder = new ContainerEnvVarBuilder(item);_visitables.get("env").remove(builder);if (this.env != null) {this.env.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromEnv(io.fabric8.kubernetes.api.builder.Predicate<ContainerEnvVarBuilder> predicate){
            if (env == null) return (A) this;
            final Iterator<ContainerEnvVarBuilder> each = env.iterator();
            final List visitables = _visitables.get("env");
            while (each.hasNext()) {
              ContainerEnvVarBuilder builder = each.next();
              if (predicate.apply(builder)) {
                visitables.remove(builder);
                each.remove();
              }
            }
            return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildEnv instead.
 * @return The buildable object.
 */
@Deprecated public java.util.List<ContainerEnvVar> getEnv(){
            return build(env);
    }

    public java.util.List<ContainerEnvVar> buildEnv(){
            return build(env);
    }

    public ContainerEnvVar buildEnv(int index){
            return this.env.get(index).build();
    }

    public ContainerEnvVar buildFirstEnv(){
            return this.env.get(0).build();
    }

    public ContainerEnvVar buildLastEnv(){
            return this.env.get(env.size() - 1).build();
    }

    public ContainerEnvVar buildMatchingEnv(io.fabric8.kubernetes.api.builder.Predicate<ContainerEnvVarBuilder> predicate){
            for (ContainerEnvVarBuilder item: env) { if(predicate.apply(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingEnv(io.fabric8.kubernetes.api.builder.Predicate<ContainerEnvVarBuilder> predicate){
            for (ContainerEnvVarBuilder item: env) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withEnv(java.util.List<ContainerEnvVar> env){
            if (this.env != null) { _visitables.get("env").removeAll(this.env);}
            if (env != null) {this.env = new ArrayList<ContainerEnvVarBuilder>(); for (ContainerEnvVar item : env){this.addToEnv(item);}} else { this.env = null;} return (A) this;
    }

    public A withEnv(ContainerEnvVar... env){
            if (this.env != null) {this.env.clear();}
            if (env != null) {for (ContainerEnvVar item :env){ this.addToEnv(item);}} return (A) this;
    }

    public Boolean hasEnv(){
            return env != null && !env.isEmpty();
    }

    public ContainerTemplateFluent.EnvNested<A> addNewEnv(){
            return new EnvNestedImpl();
    }

    public ContainerTemplateFluent.EnvNested<A> addNewEnvLike(ContainerEnvVar item){
            return new EnvNestedImpl(-1, item);
    }

    public ContainerTemplateFluent.EnvNested<A> setNewEnvLike(int index,ContainerEnvVar item){
            return new EnvNestedImpl(index, item);
    }

    public ContainerTemplateFluent.EnvNested<A> editEnv(int index){
            if (env.size() <= index) throw new RuntimeException("Can't edit env. Index exceeds size.");
            return setNewEnvLike(index, buildEnv(index));
    }

    public ContainerTemplateFluent.EnvNested<A> editFirstEnv(){
            if (env.size() == 0) throw new RuntimeException("Can't edit first env. The list is empty.");
            return setNewEnvLike(0, buildEnv(0));
    }

    public ContainerTemplateFluent.EnvNested<A> editLastEnv(){
            int index = env.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last env. The list is empty.");
            return setNewEnvLike(index, buildEnv(index));
    }

    public ContainerTemplateFluent.EnvNested<A> editMatchingEnv(io.fabric8.kubernetes.api.builder.Predicate<ContainerEnvVarBuilder> predicate){
            int index = -1;
            for (int i=0;i<env.size();i++) { 
            if (predicate.apply(env.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching env. No match found.");
            return setNewEnvLike(index, buildEnv(index));
    }

    public SecurityContext getSecurityContext(){
            return this.securityContext;
    }

    public A withSecurityContext(SecurityContext securityContext){
            this.securityContext=securityContext; return (A) this;
    }

    public Boolean hasSecurityContext(){
            return this.securityContext != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            ContainerTemplateFluentImpl that = (ContainerTemplateFluentImpl) o;
            if (env != null ? !env.equals(that.env) :that.env != null) return false;
            if (securityContext != null ? !securityContext.equals(that.securityContext) :that.securityContext != null) return false;
            return true;
    }


    public class EnvNestedImpl<N> extends ContainerEnvVarFluentImpl<ContainerTemplateFluent.EnvNested<N>> implements ContainerTemplateFluent.EnvNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ContainerEnvVarBuilder builder;
        private final int index;
    
            EnvNestedImpl(int index,ContainerEnvVar item){
                    this.index = index;
                    this.builder = new ContainerEnvVarBuilder(this, item);
            }
            EnvNestedImpl(){
                    this.index = -1;
                    this.builder = new ContainerEnvVarBuilder(this);
            }
    
    public N and(){
            return (N) ContainerTemplateFluentImpl.this.setToEnv(index, builder.build());
    }
    public N endEnv(){
            return and();
    }

}


}
